﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using OSGeo.OGR;

namespace WKBFailSample
{
	public class Work
	{
		const string _wkt = "POLYGON((1 1,5 1,5 5,1 5,1 1),(2 2, 3 2, 3 3, 2 3,2 2))";

		public static void SetEnvironment(string sPathProgram)
		{
			// Check exist variables, else, set variable
			_SetValueNewVariable("GDAL_DATA", sPathProgram + "\\gdal\\gdal-data");
			_SetValueNewVariable("GEOTIFF_CSV", sPathProgram + "\\gdal\\gdal-data");
			_SetValueNewVariable("GDAL_DRIVER_PATH", sPathProgram + "\\gdal\\gdalplugins");

			// Add variable Path new folders
			string sVarPath = System.Environment.GetEnvironmentVariable("Path");
			sVarPath += sPathProgram + ";" + sPathProgram + "\\gdal";
			System.Environment.SetEnvironmentVariable("Path", sVarPath);

			Ogr.RegisterAll();
		}
		private static void _SetValueNewVariable(string sVar, string sValue)
		{
			if (System.Environment.GetEnvironmentVariable(sVar) == null)
				System.Environment.SetEnvironmentVariable(sVar, sValue);
		}
		public static void SaveGeometry(string[] args)
		{
			string targetPath = args[0];
			string targetName = args[1];
			string driverName = "MSSQLSpatial";


			Console.WriteLine(string.Format("Getting driver {0}.", driverName));
			Driver drv = Ogr.GetDriverByName(driverName);
			if (drv == null)
			{
				Console.WriteLine(string.Format("Can't get driver {0}.", driverName));
				System.Environment.Exit(-1);
			}

			Console.WriteLine("Creating the datasource.");
			DataSource ds = drv.CreateDataSource(targetPath, new string[] { });
			if (ds == null)
			{
				Console.WriteLine("Can't create the datasource.");
				System.Environment.Exit(-1);
			}

			Console.WriteLine(string.Format("Checking layer {0}.", targetName));
			Layer layer;
			int i;
			for (i = 0; i < ds.GetLayerCount(); i++)
			{
				layer = ds.GetLayerByIndex(i);
				if (layer != null && layer.GetLayerDefn().GetName() == targetName)
				{
					Console.WriteLine(string.Format("Layer {0} already existed. Recreating it.\n", targetName));
					ds.DeleteLayer(i);
					break;
				}
			}

			Console.WriteLine(string.Format("Creating layer {0}.", targetName));
			layer = ds.CreateLayer(targetName, null, wkbGeometryType.wkbPolygon, new string[] { });
			if (layer == null)
			{
				Console.WriteLine(string.Format("Layer {0} creation failed.", targetName));
				System.Environment.Exit(-1);
			}

			Console.WriteLine("Creating feature.");
			Feature feature = new Feature(layer.GetLayerDefn());
			var geometry = Geometry.CreateFromWkt(_wkt);
			if (feature.SetGeometry(geometry) != 0)
			{
				Console.WriteLine("Failed add geometry to the feature");
				System.Environment.Exit(-1);
			}

			try
			{
				if (layer.CreateFeature(feature) != 0)
				{
					Console.WriteLine("Failed to create feature in SQL server");
					System.Environment.Exit(-1);
				}
				Console.WriteLine("Create Feature succeded.");
			}
			catch (Exception exc)
			{
				Console.WriteLine(exc.Message);
			}

		}

	}
}
